# colnade_polars

Polars backend adapter, I/O functions, and dtype mapping.

## PolarsBackend

::: colnade_polars.adapter.PolarsBackend

## Construction Functions

::: colnade_polars.io.from_dict

::: colnade_polars.io.from_rows

## I/O Functions

::: colnade_polars.io.read_parquet

::: colnade_polars.io.scan_parquet

::: colnade_polars.io.read_csv

::: colnade_polars.io.scan_csv

::: colnade_polars.io.write_parquet

::: colnade_polars.io.write_csv

## Dtype Mapping

::: colnade_polars.conversion.map_colnade_dtype

::: colnade_polars.conversion.map_polars_dtype
